@@ -23,10 +23,12 @@ namespace netxs::generics
         // In the DECSR (Secure Reset) - from 0 to 16 383 (decimal).
         // Our maximum for ITEM=int32_t is +/- 1 073 741 823 (wo two last bits)
         constexpr static unsigned subbit = 1 << (std::numeric_limits<ITEM>::digits - 2);
+        constexpr static unsigned sigbit = 1 << (std::numeric_limits<ITEM>::digits - 1);
 
     public:
-        static inline bool issub(ITEM const& value) { return value & fifo::subbit; }
-        static inline auto desub(ITEM const& value) { return static_cast<ITEM>(value & ~fifo::subbit); }
+        static inline bool issub(ITEM const& value) { return (value & subbit) != (value & sigbit) >> 1; }
+        static inline auto desub(ITEM const& value) { return static_cast<ITEM>(value & ~subbit | (value & sigbit) >> 1); }
+        static inline auto insub(ITEM const& value) { return static_cast<ITEM>(value & ~subbit | (value & sigbit ^ sigbit) >> 1); }
 
         static auto& fake() { static fifo empty; return empty; }
 
@@ -55,7 +57,7 @@ namespace netxs::generics
             if (tail != peak)
             {
                 size++;
-                *tail++ = ISSUB ? value | subbit
+                *tail++ = ISSUB ? insub(value)
                                 : value;
             }
         }
