@@ -253,6 +253,7 @@ namespace netxs::input
     using netxs::events::tier;
     using netxs::events::hook;
     using netxs::events::id_t;
+    using netxs::ansi::clip;
 
     // console: Base mouse class.
     class sysmouse
@@ -849,9 +850,9 @@ namespace netxs::input
         si32 countdown = 0;
         si32 push = 0; // hids: Mouse pressed buttons bits (Used only for foreign mouse pointer in the gate).
 
-        virtual bool clear_clip_data()                          = 0;
-        virtual void set_clip_data(twod const& size, view utf8) = 0;
-        virtual void get_clip_data(text& out_utf8)              = 0;
+        virtual bool clear_clip_data()                                 = 0;
+        virtual void set_clip_data(twod const& size, clip const& data) = 0;
+        virtual clip get_clip_data()                                   = 0;
 
         auto tooltip_enabled()
         {
